@@ -56,7 +56,6 @@
 #include <framecpp/Common/MemoryBuffer.hh>
 #include <framecpp/Common/Verify.hh>
 #include <framecpp/Dimension.hh>
-#include <framecpp/OFrameStream.hh>
 #include <framecpp/FrameH.hh>
 #include <framecpp/FrAdcData.hh>
 #include <framecpp/FrProcData.hh>
@@ -310,6 +309,23 @@ static GstFlowReturn build_and_push_frame_file(GstFrameCPPChannelMux *mux, GstCl
 					guint buffer_list_length = gst_util_uint64_scale_int_round(buffer_list_t_end - buffer_list_t_start, appdata->rate, GST_SECOND);
 					char *dest = (char *) g_malloc0(buffer_list_length * appdata->unit_size);
 
+					/*
+					 * absorb up to 1 ns of rounding
+					 * noise in the buffer list's start
+					 * and end times.  the process of
+					 * chopping up the input stream
+					 * into this list can introduce 1
+					 * ns of rounding noise because
+					 * that code has no internal,
+					 * global, count of elapsed time.
+					 */
+
+					if(buffer_list_t_start == frame_t_start - 1)
+						buffer_list_t_start++;
+					if(buffer_list_t_end == frame_t_end + 1)
+						buffer_list_t_end--;
+					g_assert_cmpuint(buffer_list_t_start, <=, buffer_list_t_end);
+
 					/*
 					 * safety checks
 					 */
@@ -324,20 +340,33 @@ static GstFlowReturn build_and_push_frame_file(GstFrameCPPChannelMux *mux, GstCl
 
 					for(; buffer_list; buffer_list = g_list_delete_link(buffer_list, buffer_list)) {
 						GstBuffer *buffer = GST_BUFFER(buffer_list->data);
+						GstClockTime buffer_t_start = GST_BUFFER_TIMESTAMP(buffer);
+						GstClockTime buffer_t_end = buffer_t_start + GST_BUFFER_DURATION(buffer);
 
 						/*
-						 * safety checks
+						 * safety checks.  again, 1
+						 * ns of rounding noise in
+						 * the buffer's start and
+						 * end times is permitted
+						 * (see above).
 						 */
 
 						g_assert(GST_BUFFER_TIMESTAMP_IS_VALID(buffer));
 						g_assert(GST_BUFFER_DURATION_IS_VALID(buffer));
-						g_assert_cmpuint(GST_BUFFER_TIMESTAMP(buffer), >=, frame_t_start);
-						g_assert_cmpuint(GST_BUFFER_TIMESTAMP(buffer) + GST_BUFFER_DURATION(buffer), <=, frame_t_end);
+						if(buffer_t_start + 1 == buffer_list_t_start)
+							buffer_t_start++;
+						if(buffer_t_end - 1 == buffer_list_t_end)
+							buffer_t_end--;
+						g_assert_cmpuint(buffer_t_start, <=, buffer_t_end);
+						g_assert_cmpuint(buffer_list_t_start, <=, buffer_t_start);
+						g_assert_cmpuint(buffer_t_end, <=, buffer_list_t_end);
 						g_assert_cmpuint(GST_BUFFER_OFFSET_END(buffer) - GST_BUFFER_OFFSET(buffer), ==, gst_util_uint64_scale_int_round(GST_BUFFER_DURATION(buffer), appdata->rate, GST_SECOND));
 
-						/* FIXME:  how to indicate gaps in frame file? */
 						if(!GST_BUFFER_FLAG_IS_SET(buffer, GST_BUFFER_FLAG_GAP))
-							memcpy(dest + gst_util_uint64_scale_int_round(GST_BUFFER_TIMESTAMP(buffer) - buffer_list_t_start, appdata->rate, GST_SECOND) * appdata->unit_size, GST_BUFFER_DATA(buffer), GST_BUFFER_SIZE(buffer));
+							memcpy(dest + gst_util_uint64_scale_int_round(buffer_t_start - buffer_list_t_start, appdata->rate, GST_SECOND) * appdata->unit_size, GST_BUFFER_DATA(buffer), GST_BUFFER_SIZE(buffer));
+						else {
+							/* FIXME:  how to indicate gaps in frame file? */
+						}
 						gst_buffer_unref(buffer);
 					}
 
@@ -353,6 +382,8 @@ static GstFlowReturn build_and_push_frame_file(GstFrameCPPChannelMux *mux, GstCl
 					case GST_FRPAD_TYPE_FRADCDATA: {
 						FrameCPP::FrAdcData adc_data(GST_PAD_NAME(data->pad), frpad->channel_group, frpad->channel_number, frpad->nbits, appdata->rate);
 						adc_data.AppendComment(frpad->comment);
+					/* FrAdc objects cannot encode an offsset */
+						g_assert_cmpuint(buffer_list_t_start, ==, frame_t_start);
 						GST_LOG_OBJECT(data->pad, "appending FrAdcData [%" GST_TIME_SECONDS_FORMAT ", %" GST_TIME_SECONDS_FORMAT ")", GST_TIME_SECONDS_ARGS(buffer_list_t_start), GST_TIME_SECONDS_ARGS(buffer_list_t_end));
 						adc_data.RefData().append(vect);
 						if(!frame->GetRawData()) {
@@ -365,7 +396,7 @@ static GstFlowReturn build_and_push_frame_file(GstFrameCPPChannelMux *mux, GstCl
 
 					case GST_FRPAD_TYPE_FRPROCDATA: {
 						/* FIXME:  history */
-						FrameCPP::FrProcData proc_data(GST_PAD_NAME(data->pad), frpad->comment, 1, 0, (double) (buffer_list_t_start - frame_t_start) / GST_SECOND, (double) (buffer_list_t_end - buffer_list_t_start) / GST_SECOND, 0.0, 0.0, 0.0, 0.0);
+						FrameCPP::FrProcData proc_data(GST_PAD_NAME(data->pad), frpad->comment, 1, 0, (double) GST_CLOCK_DIFF(frame_t_start, buffer_list_t_start) / GST_SECOND, (double) GST_CLOCK_DIFF(buffer_list_t_start, buffer_list_t_end) / GST_SECOND, 0.0, 0.0, 0.0, 0.0);
 						GST_LOG_OBJECT(data->pad, "appending FrProcData [%" GST_TIME_SECONDS_FORMAT ", %" GST_TIME_SECONDS_FORMAT ")", GST_TIME_SECONDS_ARGS(buffer_list_t_start), GST_TIME_SECONDS_ARGS(buffer_list_t_end));
 						proc_data.RefData().append(vect);
 						frame->RefProcData().append(proc_data);
@@ -373,7 +404,7 @@ static GstFlowReturn build_and_push_frame_file(GstFrameCPPChannelMux *mux, GstCl
 					}
 
 					case GST_FRPAD_TYPE_FRSIMDATA: {
-						FrameCPP::FrSimData sim_data(GST_PAD_NAME(data->pad), frpad->comment, appdata->rate, 0.0, 0.0, (double) (buffer_list_t_start - frame_t_start) / GST_SECOND);
+						FrameCPP::FrSimData sim_data(GST_PAD_NAME(data->pad), frpad->comment, appdata->rate, 0.0, 0.0, (double) GST_CLOCK_DIFF(frame_t_start, buffer_list_t_start) / GST_SECOND);
 						GST_LOG_OBJECT(data->pad, "appending FrSimData [%" GST_TIME_SECONDS_FORMAT ", %" GST_TIME_SECONDS_FORMAT ")", GST_TIME_SECONDS_ARGS(buffer_list_t_start), GST_TIME_SECONDS_ARGS(buffer_list_t_end));
 						sim_data.RefData().append(vect);
 						frame->RefSimData().append(sim_data);
