@@ -19,6 +19,15 @@
  */
 
 
+/**
+ * SECTION:framexmitsrc
+ * @short_description:  GDS framexmit broadcast receiver source element.
+ *
+ * Reviewed:  00d65a70accca228bb76bd07e89b3ec07c78f736 2014-08-13 K.
+ * Cannon, J.  Creighton, B. Sathyaprakash.
+ */
+
+
 /*
  * ========================================================================
  *
@@ -254,12 +263,12 @@ static void *receive_thread(void *arg)
 
 		len = FRAMERCV(element)->receive(data, 0, &sequence, &timestamp, &duration);
 		if(len < 0) {
+			free(data);
 			GST_ELEMENT_ERROR(element, RESOURCE, FAILED, (NULL), ("framexmit::frameRecv.receive() failed"));
 			g_mutex_lock(element->buffer_lock);
 			element->recv_status = GST_FLOW_ERROR;
 			g_cond_signal(element->received_buffer);
 			g_mutex_unlock(element->buffer_lock);
-			free(data);
 			break;
 		}
 		GST_DEBUG_OBJECT(element, "recieved %d byte buffer (seq. #%u) for [%u s, %u s)", len, sequence, timestamp, timestamp + duration);
@@ -316,7 +325,8 @@ static gboolean start(GstBaseSrc *object)
 		FRAMERCV(element)->close();
 		element->frameRecv = NULL;
 		goto done;
-	}
+	} else
+		GST_DEBUG_OBJECT(element, "framexmit::frameRecv.open(group = \"%s\", iface = \"%s\", port = %d) succeeded", element->group, element->iface, element->port);
 
 	element->recv_status = GST_FLOW_OK;
 	retval = pthread_create(&element->recv_thread, NULL, receive_thread, element);
@@ -358,6 +368,7 @@ static gboolean stop(GstBaseSrc *object)
 	FRAMERCV(element)->close();
 	delete FRAMERCV(element);
 	element->frameRecv = NULL;
+	GST_DEBUG_OBJECT(element, "framexmit::frameRecv.close()");
 
 	element->max_latency = element->min_latency = GST_CLOCK_TIME_NONE;
 
