@@ -56,8 +56,8 @@
 #include <gstlal_specgram.h>
 #include <gstlal_pad.h>
 #include <gstlal_trim.h>
-#include <gstlal_burst_triggergen.h>
 #include <gstlal_bitvectorgen.h>
+#include <audioratefaker.h>
 
 
 /*
@@ -80,9 +80,9 @@ static gboolean plugin_init(GstPlugin *plugin)
 		{"lal_mean", GSTLAL_MEAN_TYPE},
 		{"lal_specgram", GSTLAL_SPECGRAM_TYPE},
 		{"lal_pad", GST_TYPE_LALPAD},
-		{"lal_bursttriggergen", GSTLAL_BURST_TRIGGERGEN_TYPE},
 		{"lal_trim", GST_TYPE_LALTRIM},
 		{"lal_bitvectorgen", GSTLAL_BITVECTORGEN_TYPE},
+		{"audioratefaker", GST_TYPE_AUDIO_RATE_FAKER},
 		{NULL, 0},
 	};
 
